<?php

require_once '../../../../wp-load.php';
require_once 'chinadivision-common-function.php';

global $wpdb;
$db_prefix = $wpdb->prefix;

$input = file_get_contents('php://input');

if (empty($input)) {
    cd_api_response_failed('callback data can not be empty');
}

$userSignKey = $_SERVER['HTTP_X_WC_WEBHOOK_SIGNATURE'] ?? '';
if (empty($userSignKey) || strlen($userSignKey) < 32) {
    cd_api_response_failed('callback header not contain signature or signature is illegal', 2);
}
$topic = $_SERVER['HTTP_X_WC_WEBHOOK_TOPIC'] ?? '';
if (empty($topic) || !in_array($topic, ['order.created', 'order.updated'])) {
    cd_api_response_failed('callback header not contain topic or topic is illegal', 3);
}

cd_trace_log('chinadivision order callback data:');
cd_trace_log($input);

$webhooks = cd_get_webhooks($wpdb, $db_prefix);

if (empty($webhooks[$topic]) || $webhooks[$topic]['status'] != 'active') {
    cd_api_response_failed(sprintf('chinaDivision Woocommerce webhook [%s] not active, callback failed', $topic), 4);
}

$webhook = $webhooks[$topic];

$serverSignKey = base64_encode(hash_hmac('sha256', $input, $webhook['secret'], true));

if ($userSignKey !== $serverSignKey) {
    cd_api_response_failed('signature validation failed', 5);
}

$order = json_decode($input, true);
if (empty($order) || empty($order['id'])) {
    cd_api_response_failed('callback data is illegal', 6);
}

$ret = cd_create_order($order['id']);

echo is_array($ret) ? json_encode($ret, JSON_UNESCAPED_UNICODE) : $ret;
